package com.bonus.canteen.core.basic.mapper;

import java.util.List;
import com.bonus.canteen.core.basic.domain.BasicCanteen;

/**
 * 食堂信息Mapper接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface BasicCanteenMapper {
    /**
     * 查询食堂信息
     * 
     * @param canteenId 食堂信息主键
     * @return 食堂信息
     */
    public BasicCanteen selectBasicCanteenByCanteenId(Long canteenId);

    public BasicCanteen selectBasicCanteenByCanteenName(BasicCanteen basicCanteen);

    public int getBasicCanteenCountByAreaIds(Long[] areaIds);

    /**
     * 查询食堂信息列表
     * 
     * @param basicCanteen 食堂信息
     * @return 食堂信息集合
     */
    public List<BasicCanteen> selectBasicCanteenList(BasicCanteen basicCanteen);

    /**
     * 新增食堂信息
     * 
     * @param basicCanteen 食堂信息
     * @return 结果
     */
    public int insertBasicCanteen(BasicCanteen basicCanteen);

    /**
     * 修改食堂信息
     * 
     * @param basicCanteen 食堂信息
     * @return 结果
     */
    public int updateBasicCanteen(BasicCanteen basicCanteen);

    /**
     * 删除食堂信息
     * 
     * @param canteenId 食堂信息主键
     * @return 结果
     */
    public int deleteBasicCanteenByCanteenId(Long canteenId);

    /**
     * 批量删除食堂信息
     * 
     * @param canteenIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBasicCanteenByCanteenIds(Long[] canteenIds);
}
