package com.bonus.canteen.core.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.basic.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.basic.domain.BasicCanteen;
import com.bonus.canteen.core.basic.service.IBasicCanteenService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 食堂信息Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "食堂信息接口")
@RestController
@RequestMapping("/basic_canteen")
public class BasicCanteenController extends BaseController {
    @Autowired
    private IBasicCanteenService basicCanteenService;

    /**
     * 查询食堂信息列表
     */
    @ApiOperation(value = "查询食堂信息列表")
    //@RequiresPermissions("basic:canteen:list")
    @GetMapping("/list")
    public TableDataInfo list(BasicCanteen basicCanteen) {
        startPage();
        List<BasicCanteen> list = basicCanteenService.selectBasicCanteenList(basicCanteen);
        return getDataTable(list);
    }

    /**
     * 导出食堂信息列表
     */
    @ApiOperation(value = "导出食堂信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:canteen:export")
    @SysLog(title = "食堂信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出食堂信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BasicCanteen basicCanteen) {
        List<BasicCanteen> list = basicCanteenService.selectBasicCanteenList(basicCanteen);
        ExcelUtil<BasicCanteen> util = new ExcelUtil<BasicCanteen>(BasicCanteen.class);
        util.exportExcel(response, list, "食堂信息数据");
    }

    /**
     * 获取食堂信息详细信息
     */
    @ApiOperation(value = "获取食堂信息详细信息")
    //@RequiresPermissions("basic:canteen:query")
    @GetMapping(value = "/{canteenId}")
    public AjaxResult getInfo(@PathVariable("canteenId") Long canteenId) {
        return success(basicCanteenService.selectBasicCanteenByCanteenId(canteenId));
    }

    /**
     * 新增食堂信息
     */
    @ApiOperation(value = "新增食堂信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:canteen:add")
    @SysLog(title = "食堂信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增食堂信息")
    @PostMapping
    public AjaxResult add(@RequestBody BasicCanteen basicCanteen) {
        try {
            return toAjax(basicCanteenService.insertBasicCanteen(basicCanteen));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改食堂信息
     */
    @ApiOperation(value = "修改食堂信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:canteen:edit")
    @SysLog(title = "食堂信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改食堂信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody BasicCanteen basicCanteen) {
        try {
            return toAjax(basicCanteenService.updateBasicCanteen(basicCanteen));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除食堂信息
     */
    @ApiOperation(value = "删除食堂信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:canteen:remove")
    @SysLog(title = "食堂信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除食堂信息")
	@PostMapping("/del/{canteenIds}")
    public AjaxResult remove(@PathVariable Long[] canteenIds) {
        return toAjax(basicCanteenService.deleteBasicCanteenByCanteenIds(canteenIds));
    }
}
